@@ -1,9 +1,10 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 import logging
 import os
 from textwrap import TextWrapper
+from typing import TYPE_CHECKING
 
 from jrnl.exception import JrnlException
 from jrnl.messages import Message
@@ -11,9 +12,13 @@ from jrnl.messages import MsgStyle
 from jrnl.messages import MsgText
 from jrnl.plugins.text_exporter import TextExporter
 
+if TYPE_CHECKING:
+    from jrnl.journals import Entry
+    from jrnl.journals import Journal
+
 
 class FancyExporter(TextExporter):
-    """This Exporter can convert entries and journals into text with unicode box drawing characters."""
+    """This Exporter converts entries and journals into text with unicode boxes."""
 
     names = ["fancy", "boxed"]
     extension = "txt"
@@ -35,7 +40,7 @@ class FancyExporter(TextExporter):
     border_m = "┘"
 
     @classmethod
-    def export_entry(cls, entry):
+    def export_entry(cls, entry: "Entry") -> str:
         """Returns a fancy unicode representation of a single entry."""
         date_str = entry.date.strftime(entry.journal.config["timeformat"])
 
@@ -95,12 +100,14 @@ class FancyExporter(TextExporter):
         return "\n".join(card)
 
     @classmethod
-    def export_journal(cls, journal):
+    def export_journal(cls, journal) -> str:
         """Returns a unicode representation of an entire journal."""
         return "\n".join(cls.export_entry(entry) for entry in journal)
 
 
-def check_provided_linewrap_viability(linewrap, card, journal):
+def check_provided_linewrap_viability(
+    linewrap: int, card: list[str], journal: "Journal"
+):
     if len(card[0]) > linewrap:
         width_violation = len(card[0]) - linewrap
         raise JrnlException(
